const express = require('express');
const fs = require('fs');
const path = require('path');
const cors = require('cors');
const bodyParser = require('body-parser');

const app = express();
const port = 3000; // 可以根据需要修改端口号
app.use(cors());

app.use(bodyParser.json());

app.post('/createShortcut', (req, res) => {
  // folderPath：存放的路径 shortcutName： 快捷方式名称 shortcutURL： 快捷方式的访问地址
  const { folderPath, shortcutName, shortcutURL } = req.body;

  // 检查是否缺少任何一个值
  if (!folderPath || !shortcutName || !shortcutURL) {
    return res.status(400).send('少了参数！');
  }

  // 创建文件夹（如果不存在）
  if (!fs.existsSync(folderPath)) {
    fs.mkdirSync(folderPath, { recursive: true });
  }

  const shortcutFilePath = path.join(folderPath, `${shortcutName}.url`);

  // 删除旧的快捷方式文件（如果存在）
  if (fs.existsSync(shortcutFilePath)) {
    fs.unlinkSync(shortcutFilePath);
  }

  // 创建快捷方式
  const shortcutFolderPath = path.join(folderPath, shortcutName + '.url');
  const shortcutFileContent = `[InternetShortcut]\nURL=${shortcutURL}`;

  fs.writeFile(shortcutFolderPath, shortcutFileContent, (err) => {
    if (err) {
      console.error(err);
      res.status(500).send('安装失败！');
    } else {
      res.status(200).send('安装成功！');
    }
  });
});

// 本地测试的话 需要进入到当前的文件夹目录打开终端 执行 node nodeService.js 

app.listen(port, () => {
  console.log(`Server is running on port ${port}`);
});